=====================
 Reference documents
=====================

Reference documents which need to be revised over time.

.. toctree::
   :maxdepth: 1

   opens
   principles
   charter
   projects/index
   popup-teams
   technical-vision
   upstream-investment-opportunities/index
   role-of-the-tc
   new-projects-requirements
   new-language-requirements
   dropping-projects
   licensing
   base-services
   user-committee-charter
   working-groups
   service-project-naming
   project-testing-interface
   irc
   release-naming
   tags/index
   Requirements for previously-used incubation/integration process <incubation-integration-requirements>
   house-rules
   comparison-of-official-group-structures
   tc-guide
   OpenStack-name-in-external-services
   election-exceptions
   tc-chair-elections
   emerging-technology-and-inactive-projects
